@@ -1,7 +1,7 @@
 package Algorithm::Backoff::Constant;
 
-our $DATE = '2019-06-07'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-06-08'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use strict;
 use warnings;
@@ -20,6 +20,8 @@ $SPEC{new} = {
         %Algorithm::Backoff::attr_max_attempts,
         %Algorithm::Backoff::attr_jitter_factor,
         %Algorithm::Backoff::attr_delay_on_success,
+        %Algorithm::Backoff::attr_min_delay,
+        %Algorithm::Backoff::attr_max_delay,
         delay => {
             summary => 'Number of seconds to wait after a failure',
             schema => 'ufloat*',
@@ -57,7 +59,7 @@ Algorithm::Backoff::Constant - Backoff using a constant delay
 
 =head1 VERSION
 
-This document describes version 0.005 of Algorithm::Backoff::Constant (from Perl distribution Algorithm-Backoff), released on 2019-06-07.
+This document describes version 0.006 of Algorithm::Backoff::Constant (from Perl distribution Algorithm-Backoff), released on 2019-06-08.
 
 =head1 SYNOPSIS
 
@@ -82,6 +84,20 @@ This document describes version 0.005 of Algorithm::Backoff::Constant (from Perl
  my $secs = $ab->success();           # => 0
  my $secs = $ab->failure();           # => 2
 
+Illustration using CLI L<show-backoff-delays> (5 failures followed by 3
+successes):
+
+ % show-backoff-delays -a Constant --delay 2 \
+     0 0 0 0 0   1 1 1
+ 2
+ 2
+ 2
+ 2
+ 2
+ 0
+ 0
+ 0
+
 =head1 DESCRIPTION
 
 This backoff strategy is one of the simplest: it waits X second(s) after each
@@ -157,6 +173,14 @@ Note that after a success, the number of attempts is reset (as expected). So if
 max_attempts is 3, and if you fail twice then succeed, then on the next failure
 the algorithm will retry again for a maximum of 3 times.
 
+=item * B<max_delay> => I<ufloat>
+
+Maximum delay time, in seconds.
+
+=item * B<min_delay> => I<ufloat> (default: 0)
+
+Maximum delay time, in seconds.
+
 =back
 
 Return value:  (obj)
