@@ -1,7 +1,7 @@
 package Algorithm::Backoff::Exponential;
 
-our $DATE = '2019-06-07'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-06-08'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use strict;
 use warnings;
@@ -20,13 +20,9 @@ $SPEC{new} = {
         %Algorithm::Backoff::attr_max_attempts,
         %Algorithm::Backoff::attr_jitter_factor,
         %Algorithm::Backoff::attr_delay_on_success,
+        %Algorithm::Backoff::attr_min_delay,
         %Algorithm::Backoff::attr_max_delay,
-        initial_delay => {
-            summary => 'Initial delay for the first attempt after failure, '.
-                'in seconds',
-            schema => 'ufloat*',
-            req => 1,
-        },
+        %Algorithm::Backoff::attr_initial_delay,
         exponent_base => {
             schema => 'ufloat*',
             default => 2,
@@ -64,7 +60,7 @@ Algorithm::Backoff::Exponential - Backoff exponentially
 
 =head1 VERSION
 
-This document describes version 0.005 of Algorithm::Backoff::Exponential (from Perl distribution Algorithm-Backoff), released on 2019-06-07.
+This document describes version 0.006 of Algorithm::Backoff::Exponential (from Perl distribution Algorithm-Backoff), released on 2019-06-08.
 
 =head1 SYNOPSIS
 
@@ -97,6 +93,25 @@ This document describes version 0.005 of Algorithm::Backoff::Exponential (from P
  $secs = $ab->failure();   # => 100 ( min(5 * 2^5, 100) )
  $secs = $ab->success();   # => 0 (= delay_on_success)
 
+Illustration using CLI L<show-backoff-delays> (10 failures followed by 3
+successes):
+
+ % show-backoff-delays -a Exponential --initial-delay 1 --max-delay 200 \
+     0 0 0 0 0   0 0 0 0 0   1 1 1
+ 1
+ 2
+ 4
+ 8
+ 16
+ 32
+ 64
+ 128
+ 200
+ 200
+ 0
+ 0
+ 0
+
 =head1 DESCRIPTION
 
 This backoff algorithm calculates the next delay as:
@@ -188,6 +203,10 @@ the algorithm will retry again for a maximum of 3 times.
 
 Maximum delay time, in seconds.
 
+=item * B<min_delay> => I<ufloat> (default: 0)
+
+Maximum delay time, in seconds.
+
 =back
 
 Return value:  (obj)
